---
title: SixueTree 树形控件
---

本 Demo 演示形控件扩展更多操作，包括：重命名、添加子分组、上移、下移、置顶、置底、（删除/停启用）

```jsx
import React, { useState } from 'react';
import { Button } from '@alifd/next';
import SixueTree from 'sixue-tree';

const data = [
  {
    label: 'abcdadfasdfasdfasdfasdfsdafsdfsdfsdfsdf',
    key: '1',
    group: true,
    enabled: true,
    children: [
      {
        label: 'Form',
        key: '2',
        group: true,
        enabled: true,
        children: [
          {
            label: 'Input',
            key: '3',
            group: true,
            enabled: true,
            children: [
              {
                label: 'Input1',
                key: '3-1',
                group: true,
                enabled: false,
              },
              {
                label: 'Select1',
                key: '3-2',
                group: true,
                enabled: true,
                children: [],
              },
            ],
          },
          {
            label: 'Select',
            key: '4',
            group: false,
            enabled: false,
          },
        ],
      },
      {
        label: 'Display',
        key: '5',
        group: true,
        enabled: true,
        children: [
          {
            label: 'Table',
            key: '5-1',
            group: false,
            enabled: false,
          },
        ],
      },
    ],
  },
  { label: '7', key: '7', group: true, enabled: true },
  { label: '8', key: '8', group: true, enabled: true },
  { label: '9', key: '9', group: true, enabled: true },
  { label: '10', key: '10', group: true, enabled: true },
  { label: '11', key: '11', group: false, enabled: false },
  { label: '12', key: '12', group: false, disabled: false },
  { label: '13', key: '13', group: true, enabled: true },
  { label: '14', key: '14', group: true, enabled: true },
  { label: '15', key: '15', group: true, enabled: true },
  { label: '16', key: '16', group: true, enabled: true },
  { label: '17', key: '17', group: true, enabled: true },
  { label: '18', key: '18', group: true, enabled: true },
  { label: '19', key: '19', group: true, enabled: true },
  { label: '20', key: '20', group: true, enabled: true },
  { label: '21', key: '21', group: true, enabled: true },
  { label: '22', key: '22', group: true, enabled: true },
  { label: '23', key: '23', group: true, enabled: true },
  { label: '24', key: '24', group: true, enabled: true },
  { label: '25', key: '25', group: true, enabled: true },
  { label: '26', key: '26', group: true, enabled: true },
  { label: '27', key: '27', group: true, enabled: false },
  { label: '28', key: '28', group: true, enabled: true },
  { label: '29', key: '29', group: true, enabled: true },
  { label: '30', key: '30', group: true, enabled: true },
  { label: '31', key: '31', group: true, enabled: true },
  { label: '32', key: '32', group: true, enabled: true },
  { label: '33', key: '33', group: true, enabled: true },
  { label: '34', key: '34', group: true, enabled: true },
  { label: '35', key: '35', group: true, enabled: true },
  { label: '36', key: '36', group: true, enabled: true },
  { label: '37', key: '37', group: true, enabled: true },
  { label: '38', key: '38', group: true, enabled: true },
];
const data1 = [{"key":"1","label":"品类分组品类分组品类分组品类分组品类分组品类分组品类分组品类分组","group":true,"enabled":true,"parentId":"0","sort":0,"children":[{"key":"8","label":"商品品类1-1","group":true,"enabled":true,"parentId":"1","sort":2,"children":[]},{"key":"30","label":"商品品类","group":false,"enabled":true,"parentId":"1","sort":2,"children":[]}]},{"key":"59","label":"动物园动物园动物物","group":true,"enabled":true,"parentId":"0","sort":24,"children":[]},{"key":"61","label":"猫","group":true,"enabled":true,"parentId":"0","sort":30,"children":[]}]

export default function TreeView() {
  const [treeData, setTreeData] = useState(data1);
  const [selected, setSelected] = useState(['3']);
  const [expand, setExpand] = useState(['3']);
  const [treeItemInfo, setTreeItemInfo] = useState(Array || Object);

  const rename = () => {
    // 接口成功后执行
    treeItemInfo.label = `${treeItemInfo.label} - rename`;
    setTreeData([...treeData]);
  };

  const addChild = () => {
    // 接口成功后执行
    treeItemInfo.children.push({
      label: '子分组',
      key: '10006',
      group: true,
      enabled: true,
     });
    setTreeData([...treeData]);
  };

  const enableDisable = (type) => {
    console.log(type ? '启用' : '停用');
    // 接口成功后执行
    treeItemInfo.enabled = !treeItemInfo.enabled;
    setTreeData([...treeData]);
  };

  const move = (type) => {
    // 接口成功后执行
    treeFunc(type, treeData)
  };

  const remove = (type) => {
    // 接口成功后执行
    treeFunc(type, treeData);
  };

  const treeFunc = (type, data) => {
    try {
      data.forEach((item, index) => {
        if (treeItemInfo.key === item.key) {
          // 删除
          if (type === 'delete') {
             data.splice(index, 1);
          }
          // 上移
          if (type === 'up') {
            data.splice(index, 1);
            data.splice(index - 1, 0, item);
          }
          // 下移
          if (type === 'down') {
            data.splice(index, 1);
            data.splice(index + 1, 0, item);
          }
          // 置顶
          if (type === 'top') {
            data.splice(index, 1);
            data.unshift(item);
          }
          // 置底
          if (type === 'bottom') {
            data.splice(index, 1);
            data.push(item);
          }
          setTreeData([...treeData]);
          throw Error();
        }
        if (item.children) {
          treeFunc(type, item.children);
        }
      });
    } catch (e) {
      e;
    }
  }
  
  const onChange = (info) => {
    // 当前tree选中信息
    // console.log(info);
    setTreeItemInfo(info);
  };

  return (
    <div style={{position: 'relative', width: '100%', height: '500px', display: 'flex'}}>
      <div style={{display: 'flex', width: '290px', padding: '40px 26px 0'}}>
        <Button
          type='primary'
          style={{position: 'absolute',top: '0'}}
          onClick={() => {
            treeData.push({ label: '小蚂蚁', key: '105', group: true, enabled: false });
            setTreeData([...treeData]);
          }}
        >
          新建分组
        </Button>
        <SixueTree
          dataSource={treeData}
          groupingIcon='email'
          groupingMaxNum={4}
          selected={selected}
          expand={expand}
          disableShow={true}
          onChange={onChange}
          rename={rename}
          addChild={addChild}
          move={move}
          remove={remove}
          enableDisable={enableDisable}
        />
      </div>
      <div style={{flex: '1', background: '#fff'}}>
        <Button
          type='primary'
          className='buttonTop'
          onClick={() => {
            setExpand(['3']);
            setSelected(['3-1']);
          }}
        >
          setExpand方法展开分组
        </Button>
      </div>
    </div>
  )
}
```
